Documentation
¶
Index ¶
Constants ¶
const ( ExitSuccess = 0 ExitError = 1 ExitUsage = 2 ExitAuth = 3 ExitNotFound = 4 ExitConflict = 5 // HTTP 4xx range: 10 + (status - 400) ExitHTTPBadRequest = 10 ExitHTTPForbidden = 12 ExitHTTPUnprocessable = 22 // HTTP 5xx range: 60 + (status - 500) ExitHTTPInternalServer = 60 ExitHTTPBadGateway = 62 )
Exit codes following the CI/CD specification.
Variables ¶
This section is empty.
Functions ¶
func ExitCodeFromError ¶
ExitCodeFromError maps an error to the appropriate exit code.
func HTTPStatusToExitCode ¶
HTTPStatusToExitCode maps an HTTP status code to a CLI exit code.
func RootCommand ¶
RootCommand returns the root command tree for the slim aso CLI.
func RootUsageFunc ¶
RootUsageFunc renders the root help screen.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.